# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto_pixplus.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto_pixplus.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x13proto_pixplus.proto\"\xcd\x02\n\x0eIndividualTask\x12\x10\n\x08image_id\x18\x01 \x01(\t\x12\x17\n\x0finput_image_url\x18\x02 \x01(\t\x12\x1f\n\x17output_image_upload_url\x18\x03 \x01(\t\x12\x1e\n\x16output_vizu_upload_url\x18\x04 \x01(\t\x12\"\n\x1aoutput_meta_pkl_upload_url\x18\x05 \x01(\t\x12+\n#output_mask_faceplusplus_upload_url\x18\x06 \x01(\t\x12\x1a\n\x12temp_im_upload_url\x18\x07 \x01(\t\x12\x13\n\x0btemp_im_url\x18\x08 \x01(\t\x12(\n\rgt_dictionary\x18\t \x01(\x0b\x32\x11.ValidationGTDict\x12#\n\x1boutput_validation_run_infos\x18\n \x01(\x05\"\xce\x01\n\tBatchTask\x12\x18\n\x10input_images_ids\x18\x01 \x03(\t\x12\x18\n\x10input_image_urls\x18\x02 \x03(\t\x12\x1b\n\x13input_meta_pkl_urls\x18\x03 \x03(\t\x12!\n\x19output_images_upload_urls\x18\x04 \x03(\t\x12\x1f\n\x17output_vizu_upload_urls\x18\x05 \x03(\t\x12,\n$output_mask_faceplusplus_upload_urls\x18\x06 \x03(\t\"\x92\x03\n\x13PixPlusInputMessage\x12\x0f\n\x07id_user\x18\x01 \x01(\t\x12\x0e\n\x06id_job\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x05\x12\x16\n\x0epath_to_folder\x18\x04 \x01(\t\x12\x19\n\x11output_resolution\x18\x05 \x01(\r\x12\"\n\x0crequest_type\x18\x06 \x01(\x0e\x32\x0c.RequestType\x12\x1c\n\ttask_type\x18\x07 \x01(\x0e\x32\t.TaskType\x12\x1e\n\nimage_pose\x18\x08 \x01(\x0e\x32\n.ImagePose\x12*\n\x0findividual_task\x18\t \x01(\x0b\x32\x0f.IndividualTaskH\x00\x12 \n\nbatch_task\x18\n \x01(\x0b\x32\n.BatchTaskH\x00\x12,\n\x11\x63ustom_parameters\x18\x0b \x01(\x0b\x32\x11.CustomParameters\x12)\n!do_facial_individual_full_process\x18\x0c \x01(\x08\x42\x0b\n\ttask_data\"2\n\x0cServiceDebug\x12\x11\n\ttraceback\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"N\n\x10ValidationGTDict\x12\x15\n\raffine_matrix\x18\x01 \x03(\x05\x12\x10\n\x08gt_width\x18\x02 \x01(\x05\x12\x11\n\tgt_height\x18\x03 \x01(\x05\"\xeb\x01\n\x10\x43ustomParameters\x12\x1d\n\x15\x66\x61\x63\x65_background_color\x18\x01 \x01(\t\x12\'\n\x0f\x66\x61\x63\x65_zoom_level\x18\x02 \x01(\x0e\x32\x0e.FaceZoomLevel\x12\"\n\x0cocclusal_cut\x18\x03 \x01(\x0e\x32\x0c.OcclusalCut\x12\x32\n\x15intra_oral_zoom_level\x18\x04 \x01(\x0e\x32\x13.IntraOralZoomLevel\x12\x1b\n\x13use_mirror_occlusal\x18\x05 \x01(\x08\x12\x1a\n\x12use_mirror_lateral\x18\x06 \x01(\x08\"b\n\x14PixPlusOutputMessage\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0cprocess_name\x18\x02 \x01(\t\x12#\n\x0cKPI_measures\x18\x03 \x01(\x0b\x32\r.KPI_Measures\"z\n\x0cKPI_Measures\x12 \n\x18mean_affine_matrix_error\x18\x01 \x01(\x02\x12\x16\n\x0epercentage_IoU\x18\x02 \x01(\x02\x12\x17\n\x0f\x62\x62ox_diff_angle\x18\x03 \x01(\x02\x12\x17\n\x0f\x63ut_limit_error\x18\x04 \x01(\x02\"J\n\x0eQueueBatchData\x12\x10\n\x08image_id\x18\x01 \x01(\t\x12\x11\n\timg_class\x18\x02 \x01(\r\x12\x13\n\x0bsmile_value\x18\x03 \x01(\x02\"\x86\x02\n\x1aPhotoClassificationMessage\x12\x0f\n\x07id_user\x18\x01 \x01(\t\x12\x0e\n\x06id_job\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x05\x12\x16\n\x0epath_to_folder\x18\x04 \x01(\t\x12\x17\n\x0finput_image_url\x18\x05 \x01(\t\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x1e\n\nimage_pose\x18\x07 \x01(\x0e\x32\n.ImagePose\x12,\n\x11image_orientation\x18\x08 \x01(\x0e\x32\x11.ImageOrientation\x12$\n\rservice_debug\x18\t \x01(\x0b\x32\r.ServiceDebug\"\xa6\x03\n\x17IntraoralProcessMessage\x12\x0f\n\x07id_user\x18\x01 \x01(\t\x12\x0e\n\x06id_job\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x05\x12\x16\n\x0epath_to_folder\x18\x04 \x01(\t\x12\x13\n\x0bintra_class\x18\x05 \x01(\x05\x12\x19\n\x11intra_orientation\x18\x06 \x01(\x05\x12\x19\n\x11output_resolution\x18\x07 \x01(\x05\x12,\n\x11\x63ustom_parameters\x18\x08 \x01(\x0b\x32\x11.CustomParameters\x12\"\n\x0crequest_type\x18\t \x01(\x0e\x32\x0c.RequestType\x12\x1c\n\ttask_type\x18\n \x01(\x0e\x32\t.TaskType\x12(\n\x0findividual_task\x18\x0b \x01(\x0b\x32\x0f.IndividualTask\x12\x0f\n\x07success\x18\x0c \x01(\x08\x12#\n\x0cKPI_measures\x18\r \x01(\x0b\x32\r.KPI_Measures\x12$\n\rservice_debug\x18\x0e \x01(\x0b\x32\r.ServiceDebug\"\xaf\x04\n\x14\x46\x61\x63ialProcessMessage\x12\x0f\n\x07id_user\x18\x01 \x01(\t\x12\x0e\n\x06id_job\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x05\x12\x16\n\x0epath_to_folder\x18\x04 \x01(\t\x12\x14\n\x0c\x66\x61\x63ial_class\x18\x05 \x01(\x05\x12\x19\n\x11intra_orientation\x18\x06 \x01(\x05\x12\x19\n\x11output_resolution\x18\x07 \x01(\x05\x12,\n\x11\x63ustom_parameters\x18\x08 \x01(\x0b\x32\x11.CustomParameters\x12)\n!do_facial_individual_full_process\x18\t \x01(\x08\x12\"\n\x0crequest_type\x18\n \x01(\x0e\x32\x0c.RequestType\x12\x1c\n\ttask_type\x18\x0b \x01(\x0e\x32\t.TaskType\x12*\n\x0findividual_task\x18\x0c \x01(\x0b\x32\x0f.IndividualTaskH\x00\x12 \n\nbatch_task\x18\r \x01(\x0b\x32\n.BatchTaskH\x00\x12#\n\nqueue_data\x18\x0e \x03(\x0b\x32\x0f.QueueBatchData\x12\x13\n\x0bsmile_value\x18\x0f \x01(\x02\x12\x18\n\x10\x62\x61tch_parameters\x18\x10 \x01(\x08\x12\x0f\n\x07success\x18\x11 \x01(\x08\x12$\n\rservice_debug\x18\x12 \x01(\x0b\x32\r.ServiceDebugB\x0b\n\ttask_data\"\xb5\x02\n\x11TeethSeg2DMessage\x12\x0f\n\x07id_user\x18\x01 \x01(\t\x12\x0e\n\x06id_job\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x05\x12\x16\n\x0epath_to_folder\x18\x04 \x01(\t\x12\x1b\n\x13retractor_image_url\x18\x05 \x01(\t\x12\x12\n\nis_cropped\x18\x06 \x01(\x08\x12\x12\n\nis_pixplus\x18\x07 \x01(\x08\x12\x13\n\x0bintra_class\x18\x08 \x01(\x05\x12\x0f\n\x07success\x18\t \x01(\x08\x12!\n\x0eteeth_polygons\x18\n \x01(\x0b\x32\t.TeethSeg\x12 \n\x0bpixplus_seg\x18\x0b \x01(\x0b\x32\x0b.PixPlusSeg\x12$\n\rservice_debug\x18\x0c \x01(\x0b\x32\r.ServiceDebug\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\" \n\x07Polygon\x12\x15\n\x05point\x18\x01 \x03(\x0b\x32\x06.Point\"#\n\x08TeethSeg\x12\x17\n\x05tooth\x18\x01 \x03(\x0b\x32\x08.Polygon\"\x90\x01\n\nPixPlusSeg\x12\x0f\n\x07\x63\x65nters\x18\x01 \x03(\x02\x12\x0e\n\x06labels\x18\x02 \x03(\r\x12\x16\n\x0e\x64\x65tectron_mask\x18\x03 \x03(\r\x12\x13\n\x0bteethmatrix\x18\x04 \x03(\r\x12\x13\n\x0bmolarmatrix\x18\x05 \x03(\r\x12\x1f\n\tteeth_pix\x18\x06 \x03(\x0b\x32\x0c.TeethPixels\"\x1d\n\x0bTeethPixels\x12\x0e\n\x06pixels\x18\x01 \x03(\r*,\n\x0bRequestType\x12\r\n\tINFERENCE\x10\x00\x12\x0e\n\nVALIDATION\x10\x01*%\n\x08TaskType\x12\x0e\n\nINDIVIDUAL\x10\x00\x12\t\n\x05\x42\x41TCH\x10\x01*$\n\rFaceZoomLevel\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01*!\n\x0bOcclusalCut\x12\x07\n\x03SIX\x10\x00\x12\t\n\x05SEVEN\x10\x01*2\n\x12IntraOralZoomLevel\x12\r\n\tLEVEL_85P\x10\x00\x12\r\n\tLEVEL_95P\x10\x01*\x87\x02\n\tImagePose\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1a\n\x16INTRAORAL_LATERAL_LEFT\x10\x01\x12\x1b\n\x17INTRAORAL_LATERAL_RIGHT\x10\x02\x12\x1c\n\x18INTRAORAL_OCCLUSAL_LOWER\x10\x03\x12\x1c\n\x18INTRAORAL_OCCLUSAL_UPPER\x10\x04\x12\x12\n\x0e\x46\x41\x43IAL_FRONTAL\x10\x05\x12\x12\n\x0e\x46\x41\x43IAL_PROFILE\x10\x06\x12\x13\n\x0f\x46\x41\x43IAL_3_4_FACE\x10\x08\x12\x18\n\x14INTRAORAL_LOWERFRONT\x10\n\x12\n\n\x06OTHERS\x10\t\x12\x15\n\x11INTRAORAL_FRONTAL\x10\x0b*O\n\x10ImageOrientation\x12\x0c\n\x08\x44\x45GREE_0\x10\x00\x12\r\n\tDEGREE_90\x10\x01\x12\x0e\n\nDEGREE_180\x10\x02\x12\x0e\n\nDEGREE_270\x10\x03\x62\x06proto3'
)

_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='RequestType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFERENCE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATION', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3487,
  serialized_end=3531,
)
_sym_db.RegisterEnumDescriptor(_REQUESTTYPE)

RequestType = enum_type_wrapper.EnumTypeWrapper(_REQUESTTYPE)
_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='TaskType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDIVIDUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BATCH', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3533,
  serialized_end=3570,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_FACEZOOMLEVEL = _descriptor.EnumDescriptor(
  name='FaceZoomLevel',
  full_name='FaceZoomLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3572,
  serialized_end=3608,
)
_sym_db.RegisterEnumDescriptor(_FACEZOOMLEVEL)

FaceZoomLevel = enum_type_wrapper.EnumTypeWrapper(_FACEZOOMLEVEL)
_OCCLUSALCUT = _descriptor.EnumDescriptor(
  name='OcclusalCut',
  full_name='OcclusalCut',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIX', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVEN', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3610,
  serialized_end=3643,
)
_sym_db.RegisterEnumDescriptor(_OCCLUSALCUT)

OcclusalCut = enum_type_wrapper.EnumTypeWrapper(_OCCLUSALCUT)
_INTRAORALZOOMLEVEL = _descriptor.EnumDescriptor(
  name='IntraOralZoomLevel',
  full_name='IntraOralZoomLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEVEL_85P', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL_95P', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3645,
  serialized_end=3695,
)
_sym_db.RegisterEnumDescriptor(_INTRAORALZOOMLEVEL)

IntraOralZoomLevel = enum_type_wrapper.EnumTypeWrapper(_INTRAORALZOOMLEVEL)
_IMAGEPOSE = _descriptor.EnumDescriptor(
  name='ImagePose',
  full_name='ImagePose',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_LATERAL_LEFT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_LATERAL_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_OCCLUSAL_LOWER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_OCCLUSAL_UPPER', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FACIAL_FRONTAL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FACIAL_PROFILE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FACIAL_3_4_FACE', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_LOWERFRONT', index=8, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHERS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTRAORAL_FRONTAL', index=10, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3698,
  serialized_end=3961,
)
_sym_db.RegisterEnumDescriptor(_IMAGEPOSE)

ImagePose = enum_type_wrapper.EnumTypeWrapper(_IMAGEPOSE)
_IMAGEORIENTATION = _descriptor.EnumDescriptor(
  name='ImageOrientation',
  full_name='ImageOrientation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEGREE_0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEGREE_90', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEGREE_180', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEGREE_270', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3963,
  serialized_end=4042,
)
_sym_db.RegisterEnumDescriptor(_IMAGEORIENTATION)

ImageOrientation = enum_type_wrapper.EnumTypeWrapper(_IMAGEORIENTATION)
INFERENCE = 0
VALIDATION = 1
INDIVIDUAL = 0
BATCH = 1
LOW = 0
MEDIUM = 1
SIX = 0
SEVEN = 1
LEVEL_85P = 0
LEVEL_95P = 1
UNKNOWN = 0
INTRAORAL_LATERAL_LEFT = 1
INTRAORAL_LATERAL_RIGHT = 2
INTRAORAL_OCCLUSAL_LOWER = 3
INTRAORAL_OCCLUSAL_UPPER = 4
FACIAL_FRONTAL = 5
FACIAL_PROFILE = 6
FACIAL_3_4_FACE = 8
INTRAORAL_LOWERFRONT = 10
OTHERS = 9
INTRAORAL_FRONTAL = 11
DEGREE_0 = 0
DEGREE_90 = 1
DEGREE_180 = 2
DEGREE_270 = 3



_INDIVIDUALTASK = _descriptor.Descriptor(
  name='IndividualTask',
  full_name='IndividualTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='IndividualTask.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_image_url', full_name='IndividualTask.input_image_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_image_upload_url', full_name='IndividualTask.output_image_upload_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_vizu_upload_url', full_name='IndividualTask.output_vizu_upload_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_meta_pkl_upload_url', full_name='IndividualTask.output_meta_pkl_upload_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_mask_faceplusplus_upload_url', full_name='IndividualTask.output_mask_faceplusplus_upload_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temp_im_upload_url', full_name='IndividualTask.temp_im_upload_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temp_im_url', full_name='IndividualTask.temp_im_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gt_dictionary', full_name='IndividualTask.gt_dictionary', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_validation_run_infos', full_name='IndividualTask.output_validation_run_infos', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=357,
)


_BATCHTASK = _descriptor.Descriptor(
  name='BatchTask',
  full_name='BatchTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_images_ids', full_name='BatchTask.input_images_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_image_urls', full_name='BatchTask.input_image_urls', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_meta_pkl_urls', full_name='BatchTask.input_meta_pkl_urls', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_images_upload_urls', full_name='BatchTask.output_images_upload_urls', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_vizu_upload_urls', full_name='BatchTask.output_vizu_upload_urls', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_mask_faceplusplus_upload_urls', full_name='BatchTask.output_mask_faceplusplus_upload_urls', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=566,
)


_PIXPLUSINPUTMESSAGE = _descriptor.Descriptor(
  name='PixPlusInputMessage',
  full_name='PixPlusInputMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_user', full_name='PixPlusInputMessage.id_user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_job', full_name='PixPlusInputMessage.id_job', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='PixPlusInputMessage.timestamp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_to_folder', full_name='PixPlusInputMessage.path_to_folder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_resolution', full_name='PixPlusInputMessage.output_resolution', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_type', full_name='PixPlusInputMessage.request_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='PixPlusInputMessage.task_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_pose', full_name='PixPlusInputMessage.image_pose', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='individual_task', full_name='PixPlusInputMessage.individual_task', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_task', full_name='PixPlusInputMessage.batch_task', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_parameters', full_name='PixPlusInputMessage.custom_parameters', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_facial_individual_full_process', full_name='PixPlusInputMessage.do_facial_individual_full_process', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task_data', full_name='PixPlusInputMessage.task_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=569,
  serialized_end=971,
)


_SERVICEDEBUG = _descriptor.Descriptor(
  name='ServiceDebug',
  full_name='ServiceDebug',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='traceback', full_name='ServiceDebug.traceback', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ServiceDebug.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1023,
)


_VALIDATIONGTDICT = _descriptor.Descriptor(
  name='ValidationGTDict',
  full_name='ValidationGTDict',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='affine_matrix', full_name='ValidationGTDict.affine_matrix', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gt_width', full_name='ValidationGTDict.gt_width', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gt_height', full_name='ValidationGTDict.gt_height', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1103,
)


_CUSTOMPARAMETERS = _descriptor.Descriptor(
  name='CustomParameters',
  full_name='CustomParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='face_background_color', full_name='CustomParameters.face_background_color', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='face_zoom_level', full_name='CustomParameters.face_zoom_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occlusal_cut', full_name='CustomParameters.occlusal_cut', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_oral_zoom_level', full_name='CustomParameters.intra_oral_zoom_level', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_mirror_occlusal', full_name='CustomParameters.use_mirror_occlusal', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_mirror_lateral', full_name='CustomParameters.use_mirror_lateral', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1341,
)


_PIXPLUSOUTPUTMESSAGE = _descriptor.Descriptor(
  name='PixPlusOutputMessage',
  full_name='PixPlusOutputMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='PixPlusOutputMessage.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_name', full_name='PixPlusOutputMessage.process_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='KPI_measures', full_name='PixPlusOutputMessage.KPI_measures', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1441,
)


_KPI_MEASURES = _descriptor.Descriptor(
  name='KPI_Measures',
  full_name='KPI_Measures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean_affine_matrix_error', full_name='KPI_Measures.mean_affine_matrix_error', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentage_IoU', full_name='KPI_Measures.percentage_IoU', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bbox_diff_angle', full_name='KPI_Measures.bbox_diff_angle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_limit_error', full_name='KPI_Measures.cut_limit_error', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1565,
)


_QUEUEBATCHDATA = _descriptor.Descriptor(
  name='QueueBatchData',
  full_name='QueueBatchData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='QueueBatchData.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='img_class', full_name='QueueBatchData.img_class', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smile_value', full_name='QueueBatchData.smile_value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1641,
)


_PHOTOCLASSIFICATIONMESSAGE = _descriptor.Descriptor(
  name='PhotoClassificationMessage',
  full_name='PhotoClassificationMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_user', full_name='PhotoClassificationMessage.id_user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_job', full_name='PhotoClassificationMessage.id_job', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='PhotoClassificationMessage.timestamp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_to_folder', full_name='PhotoClassificationMessage.path_to_folder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_image_url', full_name='PhotoClassificationMessage.input_image_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='PhotoClassificationMessage.success', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_pose', full_name='PhotoClassificationMessage.image_pose', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_orientation', full_name='PhotoClassificationMessage.image_orientation', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_debug', full_name='PhotoClassificationMessage.service_debug', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1906,
)


_INTRAORALPROCESSMESSAGE = _descriptor.Descriptor(
  name='IntraoralProcessMessage',
  full_name='IntraoralProcessMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_user', full_name='IntraoralProcessMessage.id_user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_job', full_name='IntraoralProcessMessage.id_job', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='IntraoralProcessMessage.timestamp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_to_folder', full_name='IntraoralProcessMessage.path_to_folder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_class', full_name='IntraoralProcessMessage.intra_class', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_orientation', full_name='IntraoralProcessMessage.intra_orientation', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_resolution', full_name='IntraoralProcessMessage.output_resolution', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_parameters', full_name='IntraoralProcessMessage.custom_parameters', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_type', full_name='IntraoralProcessMessage.request_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='IntraoralProcessMessage.task_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='individual_task', full_name='IntraoralProcessMessage.individual_task', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='IntraoralProcessMessage.success', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='KPI_measures', full_name='IntraoralProcessMessage.KPI_measures', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_debug', full_name='IntraoralProcessMessage.service_debug', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=2331,
)


_FACIALPROCESSMESSAGE = _descriptor.Descriptor(
  name='FacialProcessMessage',
  full_name='FacialProcessMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_user', full_name='FacialProcessMessage.id_user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_job', full_name='FacialProcessMessage.id_job', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FacialProcessMessage.timestamp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_to_folder', full_name='FacialProcessMessage.path_to_folder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='facial_class', full_name='FacialProcessMessage.facial_class', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_orientation', full_name='FacialProcessMessage.intra_orientation', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_resolution', full_name='FacialProcessMessage.output_resolution', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_parameters', full_name='FacialProcessMessage.custom_parameters', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_facial_individual_full_process', full_name='FacialProcessMessage.do_facial_individual_full_process', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_type', full_name='FacialProcessMessage.request_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_type', full_name='FacialProcessMessage.task_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='individual_task', full_name='FacialProcessMessage.individual_task', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_task', full_name='FacialProcessMessage.batch_task', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_data', full_name='FacialProcessMessage.queue_data', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smile_value', full_name='FacialProcessMessage.smile_value', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_parameters', full_name='FacialProcessMessage.batch_parameters', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='FacialProcessMessage.success', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_debug', full_name='FacialProcessMessage.service_debug', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task_data', full_name='FacialProcessMessage.task_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2334,
  serialized_end=2893,
)


_TEETHSEG2DMESSAGE = _descriptor.Descriptor(
  name='TeethSeg2DMessage',
  full_name='TeethSeg2DMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_user', full_name='TeethSeg2DMessage.id_user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_job', full_name='TeethSeg2DMessage.id_job', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='TeethSeg2DMessage.timestamp', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_to_folder', full_name='TeethSeg2DMessage.path_to_folder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retractor_image_url', full_name='TeethSeg2DMessage.retractor_image_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_cropped', full_name='TeethSeg2DMessage.is_cropped', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_pixplus', full_name='TeethSeg2DMessage.is_pixplus', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intra_class', full_name='TeethSeg2DMessage.intra_class', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='TeethSeg2DMessage.success', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teeth_polygons', full_name='TeethSeg2DMessage.teeth_polygons', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixplus_seg', full_name='TeethSeg2DMessage.pixplus_seg', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_debug', full_name='TeethSeg2DMessage.service_debug', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2896,
  serialized_end=3205,
)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='Point.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='Point.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3207,
  serialized_end=3236,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='Polygon.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3238,
  serialized_end=3270,
)


_TEETHSEG = _descriptor.Descriptor(
  name='TeethSeg',
  full_name='TeethSeg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tooth', full_name='TeethSeg.tooth', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3272,
  serialized_end=3307,
)


_PIXPLUSSEG = _descriptor.Descriptor(
  name='PixPlusSeg',
  full_name='PixPlusSeg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='centers', full_name='PixPlusSeg.centers', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='PixPlusSeg.labels', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detectron_mask', full_name='PixPlusSeg.detectron_mask', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teethmatrix', full_name='PixPlusSeg.teethmatrix', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='molarmatrix', full_name='PixPlusSeg.molarmatrix', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teeth_pix', full_name='PixPlusSeg.teeth_pix', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3454,
)


_TEETHPIXELS = _descriptor.Descriptor(
  name='TeethPixels',
  full_name='TeethPixels',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pixels', full_name='TeethPixels.pixels', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3456,
  serialized_end=3485,
)

_INDIVIDUALTASK.fields_by_name['gt_dictionary'].message_type = _VALIDATIONGTDICT
_PIXPLUSINPUTMESSAGE.fields_by_name['request_type'].enum_type = _REQUESTTYPE
_PIXPLUSINPUTMESSAGE.fields_by_name['task_type'].enum_type = _TASKTYPE
_PIXPLUSINPUTMESSAGE.fields_by_name['image_pose'].enum_type = _IMAGEPOSE
_PIXPLUSINPUTMESSAGE.fields_by_name['individual_task'].message_type = _INDIVIDUALTASK
_PIXPLUSINPUTMESSAGE.fields_by_name['batch_task'].message_type = _BATCHTASK
_PIXPLUSINPUTMESSAGE.fields_by_name['custom_parameters'].message_type = _CUSTOMPARAMETERS
_PIXPLUSINPUTMESSAGE.oneofs_by_name['task_data'].fields.append(
  _PIXPLUSINPUTMESSAGE.fields_by_name['individual_task'])
_PIXPLUSINPUTMESSAGE.fields_by_name['individual_task'].containing_oneof = _PIXPLUSINPUTMESSAGE.oneofs_by_name['task_data']
_PIXPLUSINPUTMESSAGE.oneofs_by_name['task_data'].fields.append(
  _PIXPLUSINPUTMESSAGE.fields_by_name['batch_task'])
_PIXPLUSINPUTMESSAGE.fields_by_name['batch_task'].containing_oneof = _PIXPLUSINPUTMESSAGE.oneofs_by_name['task_data']
_CUSTOMPARAMETERS.fields_by_name['face_zoom_level'].enum_type = _FACEZOOMLEVEL
_CUSTOMPARAMETERS.fields_by_name['occlusal_cut'].enum_type = _OCCLUSALCUT
_CUSTOMPARAMETERS.fields_by_name['intra_oral_zoom_level'].enum_type = _INTRAORALZOOMLEVEL
_PIXPLUSOUTPUTMESSAGE.fields_by_name['KPI_measures'].message_type = _KPI_MEASURES
_PHOTOCLASSIFICATIONMESSAGE.fields_by_name['image_pose'].enum_type = _IMAGEPOSE
_PHOTOCLASSIFICATIONMESSAGE.fields_by_name['image_orientation'].enum_type = _IMAGEORIENTATION
_PHOTOCLASSIFICATIONMESSAGE.fields_by_name['service_debug'].message_type = _SERVICEDEBUG
_INTRAORALPROCESSMESSAGE.fields_by_name['custom_parameters'].message_type = _CUSTOMPARAMETERS
_INTRAORALPROCESSMESSAGE.fields_by_name['request_type'].enum_type = _REQUESTTYPE
_INTRAORALPROCESSMESSAGE.fields_by_name['task_type'].enum_type = _TASKTYPE
_INTRAORALPROCESSMESSAGE.fields_by_name['individual_task'].message_type = _INDIVIDUALTASK
_INTRAORALPROCESSMESSAGE.fields_by_name['KPI_measures'].message_type = _KPI_MEASURES
_INTRAORALPROCESSMESSAGE.fields_by_name['service_debug'].message_type = _SERVICEDEBUG
_FACIALPROCESSMESSAGE.fields_by_name['custom_parameters'].message_type = _CUSTOMPARAMETERS
_FACIALPROCESSMESSAGE.fields_by_name['request_type'].enum_type = _REQUESTTYPE
_FACIALPROCESSMESSAGE.fields_by_name['task_type'].enum_type = _TASKTYPE
_FACIALPROCESSMESSAGE.fields_by_name['individual_task'].message_type = _INDIVIDUALTASK
_FACIALPROCESSMESSAGE.fields_by_name['batch_task'].message_type = _BATCHTASK
_FACIALPROCESSMESSAGE.fields_by_name['queue_data'].message_type = _QUEUEBATCHDATA
_FACIALPROCESSMESSAGE.fields_by_name['service_debug'].message_type = _SERVICEDEBUG
_FACIALPROCESSMESSAGE.oneofs_by_name['task_data'].fields.append(
  _FACIALPROCESSMESSAGE.fields_by_name['individual_task'])
_FACIALPROCESSMESSAGE.fields_by_name['individual_task'].containing_oneof = _FACIALPROCESSMESSAGE.oneofs_by_name['task_data']
_FACIALPROCESSMESSAGE.oneofs_by_name['task_data'].fields.append(
  _FACIALPROCESSMESSAGE.fields_by_name['batch_task'])
_FACIALPROCESSMESSAGE.fields_by_name['batch_task'].containing_oneof = _FACIALPROCESSMESSAGE.oneofs_by_name['task_data']
_TEETHSEG2DMESSAGE.fields_by_name['teeth_polygons'].message_type = _TEETHSEG
_TEETHSEG2DMESSAGE.fields_by_name['pixplus_seg'].message_type = _PIXPLUSSEG
_TEETHSEG2DMESSAGE.fields_by_name['service_debug'].message_type = _SERVICEDEBUG
_POLYGON.fields_by_name['point'].message_type = _POINT
_TEETHSEG.fields_by_name['tooth'].message_type = _POLYGON
_PIXPLUSSEG.fields_by_name['teeth_pix'].message_type = _TEETHPIXELS
DESCRIPTOR.message_types_by_name['IndividualTask'] = _INDIVIDUALTASK
DESCRIPTOR.message_types_by_name['BatchTask'] = _BATCHTASK
DESCRIPTOR.message_types_by_name['PixPlusInputMessage'] = _PIXPLUSINPUTMESSAGE
DESCRIPTOR.message_types_by_name['ServiceDebug'] = _SERVICEDEBUG
DESCRIPTOR.message_types_by_name['ValidationGTDict'] = _VALIDATIONGTDICT
DESCRIPTOR.message_types_by_name['CustomParameters'] = _CUSTOMPARAMETERS
DESCRIPTOR.message_types_by_name['PixPlusOutputMessage'] = _PIXPLUSOUTPUTMESSAGE
DESCRIPTOR.message_types_by_name['KPI_Measures'] = _KPI_MEASURES
DESCRIPTOR.message_types_by_name['QueueBatchData'] = _QUEUEBATCHDATA
DESCRIPTOR.message_types_by_name['PhotoClassificationMessage'] = _PHOTOCLASSIFICATIONMESSAGE
DESCRIPTOR.message_types_by_name['IntraoralProcessMessage'] = _INTRAORALPROCESSMESSAGE
DESCRIPTOR.message_types_by_name['FacialProcessMessage'] = _FACIALPROCESSMESSAGE
DESCRIPTOR.message_types_by_name['TeethSeg2DMessage'] = _TEETHSEG2DMESSAGE
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['TeethSeg'] = _TEETHSEG
DESCRIPTOR.message_types_by_name['PixPlusSeg'] = _PIXPLUSSEG
DESCRIPTOR.message_types_by_name['TeethPixels'] = _TEETHPIXELS
DESCRIPTOR.enum_types_by_name['RequestType'] = _REQUESTTYPE
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
DESCRIPTOR.enum_types_by_name['FaceZoomLevel'] = _FACEZOOMLEVEL
DESCRIPTOR.enum_types_by_name['OcclusalCut'] = _OCCLUSALCUT
DESCRIPTOR.enum_types_by_name['IntraOralZoomLevel'] = _INTRAORALZOOMLEVEL
DESCRIPTOR.enum_types_by_name['ImagePose'] = _IMAGEPOSE
DESCRIPTOR.enum_types_by_name['ImageOrientation'] = _IMAGEORIENTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IndividualTask = _reflection.GeneratedProtocolMessageType('IndividualTask', (_message.Message,), {
  'DESCRIPTOR' : _INDIVIDUALTASK,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:IndividualTask)
  })
_sym_db.RegisterMessage(IndividualTask)

BatchTask = _reflection.GeneratedProtocolMessageType('BatchTask', (_message.Message,), {
  'DESCRIPTOR' : _BATCHTASK,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:BatchTask)
  })
_sym_db.RegisterMessage(BatchTask)

PixPlusInputMessage = _reflection.GeneratedProtocolMessageType('PixPlusInputMessage', (_message.Message,), {
  'DESCRIPTOR' : _PIXPLUSINPUTMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:PixPlusInputMessage)
  })
_sym_db.RegisterMessage(PixPlusInputMessage)

ServiceDebug = _reflection.GeneratedProtocolMessageType('ServiceDebug', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEDEBUG,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:ServiceDebug)
  })
_sym_db.RegisterMessage(ServiceDebug)

ValidationGTDict = _reflection.GeneratedProtocolMessageType('ValidationGTDict', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATIONGTDICT,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:ValidationGTDict)
  })
_sym_db.RegisterMessage(ValidationGTDict)

CustomParameters = _reflection.GeneratedProtocolMessageType('CustomParameters', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMPARAMETERS,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:CustomParameters)
  })
_sym_db.RegisterMessage(CustomParameters)

PixPlusOutputMessage = _reflection.GeneratedProtocolMessageType('PixPlusOutputMessage', (_message.Message,), {
  'DESCRIPTOR' : _PIXPLUSOUTPUTMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:PixPlusOutputMessage)
  })
_sym_db.RegisterMessage(PixPlusOutputMessage)

KPI_Measures = _reflection.GeneratedProtocolMessageType('KPI_Measures', (_message.Message,), {
  'DESCRIPTOR' : _KPI_MEASURES,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:KPI_Measures)
  })
_sym_db.RegisterMessage(KPI_Measures)

QueueBatchData = _reflection.GeneratedProtocolMessageType('QueueBatchData', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEBATCHDATA,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:QueueBatchData)
  })
_sym_db.RegisterMessage(QueueBatchData)

PhotoClassificationMessage = _reflection.GeneratedProtocolMessageType('PhotoClassificationMessage', (_message.Message,), {
  'DESCRIPTOR' : _PHOTOCLASSIFICATIONMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:PhotoClassificationMessage)
  })
_sym_db.RegisterMessage(PhotoClassificationMessage)

IntraoralProcessMessage = _reflection.GeneratedProtocolMessageType('IntraoralProcessMessage', (_message.Message,), {
  'DESCRIPTOR' : _INTRAORALPROCESSMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:IntraoralProcessMessage)
  })
_sym_db.RegisterMessage(IntraoralProcessMessage)

FacialProcessMessage = _reflection.GeneratedProtocolMessageType('FacialProcessMessage', (_message.Message,), {
  'DESCRIPTOR' : _FACIALPROCESSMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:FacialProcessMessage)
  })
_sym_db.RegisterMessage(FacialProcessMessage)

TeethSeg2DMessage = _reflection.GeneratedProtocolMessageType('TeethSeg2DMessage', (_message.Message,), {
  'DESCRIPTOR' : _TEETHSEG2DMESSAGE,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:TeethSeg2DMessage)
  })
_sym_db.RegisterMessage(TeethSeg2DMessage)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:Point)
  })
_sym_db.RegisterMessage(Point)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:Polygon)
  })
_sym_db.RegisterMessage(Polygon)

TeethSeg = _reflection.GeneratedProtocolMessageType('TeethSeg', (_message.Message,), {
  'DESCRIPTOR' : _TEETHSEG,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:TeethSeg)
  })
_sym_db.RegisterMessage(TeethSeg)

PixPlusSeg = _reflection.GeneratedProtocolMessageType('PixPlusSeg', (_message.Message,), {
  'DESCRIPTOR' : _PIXPLUSSEG,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:PixPlusSeg)
  })
_sym_db.RegisterMessage(PixPlusSeg)

TeethPixels = _reflection.GeneratedProtocolMessageType('TeethPixels', (_message.Message,), {
  'DESCRIPTOR' : _TEETHPIXELS,
  '__module__' : 'proto_pixplus_pb2'
  # @@protoc_insertion_point(class_scope:TeethPixels)
  })
_sym_db.RegisterMessage(TeethPixels)


# @@protoc_insertion_point(module_scope)